@@ -28,12 +28,13 @@ References:
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.bech32 import Bech32ChecksumError, SegwitBech32Decoder, SegwitBech32Encoder
 from bip_utils.ecc import IPublicKey
-from bip_utils.utils.misc import CryptoUtils
+from bip_utils.utils.crypto import Hash160
 
 
 class P2WPKHAddrConst:
@@ -59,7 +60,7 @@ class P2WPKHAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            hrp (str): HRP
+            hrp (str): Expected HRP
 
         Returns:
             bytes: Public key hash bytes
@@ -112,11 +113,8 @@ class P2WPKHAddrEncoder(IAddrEncoder):
         pub_key_obj = AddrKeyValidator.ValidateAndGetSecp256k1Key(pub_key)
         return SegwitBech32Encoder.Encode(hrp,
                                           P2WPKHAddrConst.WITNESS_VER,
-                                          CryptoUtils.Hash160(pub_key_obj.RawCompressed().ToBytes()))
+                                          Hash160.QuickDigest(pub_key_obj.RawCompressed().ToBytes()))
 
 
-class P2WPKHAddr(P2WPKHAddrEncoder):
-    """
-    P2WPKH address class.
-    Only kept for compatibility, P2WPKHAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+P2WPKHAddr = P2WPKHAddrEncoder
