@@ -22,10 +22,11 @@
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
+from bip_utils.addr.eth_addr import EthAddrConst, EthAddrDecoder, EthAddrEncoder
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
-from bip_utils.addr.eth_addr import EthAddrConst, EthAddrDecoder, EthAddrEncoder
 from bip_utils.base58 import Base58ChecksumError, Base58Decoder, Base58Encoder
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import IPublicKey
@@ -63,12 +64,12 @@ class TrxAddrDecoder(IAddrDecoder):
         else:
             # Validate length
             AddrDecUtils.ValidateLength(addr_dec,
-                                        (EthAddrConst.ADDR_LEN // 2) + len(CoinsConf.Tron.Params("addr_prefix")))
+                                        (EthAddrConst.ADDR_LEN // 2) + len(CoinsConf.Tron.ParamByKey("addr_prefix")))
             # Validate and remove prefix
             addr_no_prefix = AddrDecUtils.ValidateAndRemovePrefix(addr_dec,
-                                                                  CoinsConf.Tron.Params("addr_prefix"))
+                                                                  CoinsConf.Tron.ParamByKey("addr_prefix"))
 
-            return EthAddrDecoder.DecodeAddr(CoinsConf.Ethereum.Params("addr_prefix")
+            return EthAddrDecoder.DecodeAddr(CoinsConf.Ethereum.ParamByKey("addr_prefix")
                                              + BytesUtils.ToHexString(addr_no_prefix),
                                              skip_chksum_enc=True)
 
@@ -100,11 +101,8 @@ class TrxAddrEncoder(IAddrEncoder):
         # Get address in Ethereum format (remove "0x" at the beginning)
         eth_addr = EthAddrEncoder.EncodeKey(pub_key)[2:]
         # Add prefix and encode
-        return Base58Encoder.CheckEncode(CoinsConf.Tron.Params("addr_prefix") + BytesUtils.FromHexString(eth_addr))
+        return Base58Encoder.CheckEncode(CoinsConf.Tron.ParamByKey("addr_prefix") + BytesUtils.FromHexString(eth_addr))
 
 
-class TrxAddr(TrxAddrEncoder):
-    """
-    Tron address class.
-    Only kept for compatibility, TrxAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+TrxAddr = TrxAddrEncoder
