@@ -22,13 +22,15 @@
 
 # Imports
 from typing import Any, Optional, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.base58 import Base58XmrDecoder, Base58XmrEncoder
 from bip_utils.ecc import Ed25519MoneroPublicKey, IPublicKey
-from bip_utils.utils.misc import BytesUtils, CryptoUtils
+from bip_utils.utils.crypto import Kekkak256
+from bip_utils.utils.misc import BytesUtils
 
 
 class XmrAddrConst:
@@ -54,7 +56,7 @@ class _XmrAddrUtils:
         Returns:
             bytes: Computed checksum
         """
-        return CryptoUtils.Kekkak256(payload_bytes)[:XmrAddrConst.CHECKSUM_BYTE_LEN]
+        return Kekkak256.QuickDigest(payload_bytes)[:XmrAddrConst.CHECKSUM_BYTE_LEN]
 
     @staticmethod
     def DecodeAddr(addr: str,
@@ -91,9 +93,10 @@ class _XmrAddrUtils:
                                         Ed25519MoneroPublicKey.CompressedLength() * 2)
         except ValueError as ex:
             # Validate length with payment ID
-            AddrDecUtils.ValidateLength(payload_bytes,
-                                        (Ed25519MoneroPublicKey.CompressedLength() * 2)
-                                        + XmrAddrConst.PAYMENT_ID_BYTE_LEN)
+            AddrDecUtils.ValidateLength(
+                payload_bytes,
+                (Ed25519MoneroPublicKey.CompressedLength() * 2) + XmrAddrConst.PAYMENT_ID_BYTE_LEN
+            )
             # Check payment ID
             if payment_id_bytes is None or len(payment_id_bytes) != XmrAddrConst.PAYMENT_ID_BYTE_LEN:
                 raise ValueError("Invalid payment ID") from ex
@@ -165,7 +168,7 @@ class XmrAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            net_ver (bytes): Net version
+            net_ver (bytes): Expected net version
 
         Returns:
             bytes: Public spend (first) and view (second) keys joined together
@@ -174,7 +177,6 @@ class XmrAddrDecoder(IAddrDecoder):
             ValueError: If the address encoding is not valid
         """
         net_ver = kwargs["net_ver"]
-
         return _XmrAddrUtils.DecodeAddr(addr, net_ver)
 
 
@@ -211,13 +213,6 @@ class XmrAddrEncoder(IAddrEncoder):
         return _XmrAddrUtils.EncodeKey(pub_key, pub_vkey, net_ver)
 
 
-class XmrAddr(XmrAddrEncoder):
-    """
-    Monero address class.
-    Only kept for compatibility, XmrAddrEncoder shall be used instead.
-    """
-
-
 class XmrIntegratedAddrDecoder(IAddrDecoder):
     """
     Monero integrated address decoder class.
@@ -234,8 +229,8 @@ class XmrIntegratedAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            net_ver (bytes)   : Net version
-            payment_id (bytes): Payment ID
+            net_ver (bytes)   : Expected net version
+            payment_id (bytes): Expected payment ID
 
         Returns:
             bytes: Public spend (first) and view (second) keys joined together
@@ -245,7 +240,6 @@ class XmrIntegratedAddrDecoder(IAddrDecoder):
         """
         net_ver = kwargs["net_ver"]
         payment_id = kwargs["payment_id"]
-
         return _XmrAddrUtils.DecodeAddr(addr, net_ver, payment_id)
 
 
@@ -283,8 +277,6 @@ class XmrIntegratedAddrEncoder(IAddrEncoder):
         return _XmrAddrUtils.EncodeKey(pub_key, pub_vkey, net_ver, payment_id)
 
 
-class XmrIntegratedAddr(XmrIntegratedAddrEncoder):
-    """
-    Monero integrated address class.
-    Only kept for compatibility, XmrIntegratedAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder classes shall be used instead
+XmrAddr = XmrAddrEncoder
+XmrIntegratedAddr = XmrIntegratedAddrEncoder
