@@ -25,10 +25,11 @@ Reference: https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki
 
 # Imports
 from bip_utils.bip.bip39.bip39_entropy_generator import Bip39EntropyGenerator
-from bip_utils.bip.bip39.bip39_mnemonic import Bip39MnemonicConst, Bip39Languages, Bip39Mnemonic
+from bip_utils.bip.bip39.bip39_mnemonic import Bip39Languages, Bip39Mnemonic, Bip39MnemonicConst
 from bip_utils.bip.bip39.bip39_mnemonic_utils import Bip39WordsListGetter
-from bip_utils.utils.misc import BytesUtils, CryptoUtils, IntegerUtils
-from bip_utils.utils.mnemonic import MnemonicEncoderBase, Mnemonic
+from bip_utils.utils.crypto import Sha256
+from bip_utils.utils.misc import BytesUtils, IntegerUtils
+from bip_utils.utils.mnemonic import Mnemonic, MnemonicEncoderBase
 
 
 class Bip39MnemonicEncoder(MnemonicEncoderBase):
@@ -74,8 +75,8 @@ class Bip39MnemonicEncoder(MnemonicEncoderBase):
         # Convert entropy to binary string
         entropy_bin_str = BytesUtils.ToBinaryStr(entropy_bytes, entropy_byte_len * 8)
         # Get entropy hash as binary string
-        entropy_hash_bin_str = BytesUtils.ToBinaryStr(CryptoUtils.Sha256(entropy_bytes),
-                                                      CryptoUtils.Sha256DigestSize() * 8)
+        entropy_hash_bin_str = BytesUtils.ToBinaryStr(Sha256.QuickDigest(entropy_bytes),
+                                                      Sha256.DigestSize() * 8)
         # Get mnemonic binary string by concatenating entropy and checksum
         mnemonic_bin_str = entropy_bin_str + entropy_hash_bin_str[:entropy_byte_len // 4]
 
