@@ -25,11 +25,12 @@ Reference: https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki
 
 # Imports
 from typing import Union
-from bip_utils.bip.bip32 import Bip32Utils, Bip32KeyData
-from bip_utils.bip.bip44_base import Bip44Changes, Bip44Levels, Bip44Base
+
+from bip_utils.bip.bip32 import Bip32KeyData, Bip32KeyIndex
+from bip_utils.bip.bip44_base import Bip44Base, Bip44Changes, Bip44Levels
 from bip_utils.bip.conf.bip44 import Bip44ConfGetter
 from bip_utils.bip.conf.common import BipCoins
-from bip_utils.ecc import IPublicKey, IPrivateKey
+from bip_utils.ecc import IPrivateKey, IPublicKey
 
 
 class Bip44Const:
@@ -38,7 +39,7 @@ class Bip44Const:
     # Specification name
     SPEC_NAME: str = "BIP-0044"
     # Purpose
-    PURPOSE: int = Bip32Utils.HardenIndex(44)
+    PURPOSE: int = Bip32KeyIndex.HardenIndex(44)
 
 
 class Bip44(Bip44Base):
@@ -57,8 +58,6 @@ class Bip44(Bip44Base):
                  coin_type: BipCoins) -> Bip44Base:
         """
         Create a Bip44Base object from the specified seed (e.g. BIP39 seed).
-        The test net flag is automatically set when the coin is derived. However, if you want to get the correct master
-        or purpose keys, you have to specify here if it's a test net.
 
         Args:
             seed_bytes (bytes)  : Seed bytes
@@ -156,27 +155,12 @@ class Bip44(Bip44Base):
                                   key_data)
 
     #
-    # Override methods
+    # Overridden abstract methods
     #
 
-    def DeriveDefaultPath(self) -> Bip44Base:
-        """
-        Derive a child key from the purpose and return a new Bip44Base object.
-        It calls the underlying _PurposeGeneric method with the current object as parameter.
-
-        Returns:
-            Bip44Base object: Bip44Base object
-
-        Raises:
-            Bip44DepthError: If current depth is not suitable for deriving keys
-            Bip32KeyError: If the derivation results in an invalid key
-        """
-        return self._DeriveDefaultPathGeneric(self, Bip44Const.PURPOSE)
-
     def Purpose(self) -> Bip44Base:
         """
         Derive a child key from the purpose and return a new Bip44Base object.
-        It calls the underlying _PurposeGeneric method with the current object as parameter.
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -185,12 +169,11 @@ class Bip44(Bip44Base):
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        return self._PurposeGeneric(self, Bip44Const.PURPOSE)
+        return self._PurposeGeneric(Bip44Const.PURPOSE)
 
     def Coin(self) -> Bip44Base:
         """
         Derive a child key from the coin type specified at construction and return a new Bip44Base object.
-        It calls the underlying _CoinGeneric method with the current object as parameter.
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -199,13 +182,12 @@ class Bip44(Bip44Base):
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        return self._CoinGeneric(self)
+        return self._CoinGeneric()
 
     def Account(self,
                 acc_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified account index and return a new Bip44Base object.
-        It calls the underlying _AccountGeneric method with the current object as parameter.
 
         Args:
             acc_idx (int): Account index
@@ -217,13 +199,12 @@ class Bip44(Bip44Base):
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        return self._AccountGeneric(self, acc_idx)
+        return self._AccountGeneric(acc_idx)
 
     def Change(self,
                change_type: Bip44Changes) -> Bip44Base:
         """
         Derive a child key from the specified change type and return a new Bip44Base object.
-        It calls the underlying _ChangeGeneric method with the current object as parameter.
 
         Args:
             change_type (Bip44Changes): Change type, must a Bip44Changes enum
@@ -232,17 +213,16 @@ class Bip44(Bip44Base):
             Bip44Base object: Bip44Base object
 
         Raises:
-            TypeError: If chain index is not a Bip44Changes enum
+            TypeError: If change type is not a Bip44Changes enum
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        return self._ChangeGeneric(self, change_type)
+        return self._ChangeGeneric(change_type)
 
     def AddressIndex(self,
                      addr_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified address index and return a new Bip44Base object.
-        It calls the underlying _AddressIndexGeneric method with the current object as parameter.
 
         Args:
             addr_idx (int): Address index
@@ -254,7 +234,7 @@ class Bip44(Bip44Base):
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        return self._AddressIndexGeneric(self, addr_idx)
+        return self._AddressIndexGeneric(addr_idx)
 
     @staticmethod
     def SpecName() -> str:
