@@ -22,6 +22,7 @@
 
 # Imports
 from enum import auto, unique
+
 from bip_utils.bip.conf.common.bip_coins import BipCoins
 
 
@@ -43,6 +44,8 @@ class Bip44Coins(BipCoins):
     BITCOIN_CASH = auto()
     BITCOIN_CASH_SLP = auto()
     BITCOIN_SV = auto()
+    CARDANO_BYRON_ICARUS = auto()
+    CARDANO_BYRON_LEDGER = auto()
     CELO = auto()
     CERTIK = auto()
     CHIHUAHUA = auto()
@@ -52,6 +55,7 @@ class Bip44Coins(BipCoins):
     ECASH = auto()
     ELROND = auto()
     EOS = auto()
+    ERGO = auto()
     ETHEREUM = auto()
     ETHEREUM_CLASSIC = auto()
     FANTOM_OPERA = auto()
@@ -98,5 +102,6 @@ class Bip44Coins(BipCoins):
     DASH_TESTNET = auto()
     DOGECOIN_TESTNET = auto()
     ECASH_TESTNET = auto()
+    ERGO_TESTNET = auto()
     LITECOIN_TESTNET = auto()
     ZCASH_TESTNET = auto()
