@@ -22,22 +22,23 @@
 
 # Imports
 from bip_utils.addr import (
-    AlgoAddrEncoder, AtomAddrEncoder, AvaxPChainAddrEncoder, AvaxXChainAddrEncoder, BchP2PKHAddrEncoder,
-    EgldAddrEncoder, EosAddrEncoder, EthAddrEncoder, FilSecp256k1AddrEncoder, NanoAddrEncoder, NearAddrEncoder,
-    NeoAddrEncoder, OkexAddrEncoder, OneAddrEncoder, P2PKHAddrEncoder, SolAddrEncoder,
-    SubstrateEd25519AddrEncoder, TrxAddrEncoder, XlmAddrTypes, XlmAddrEncoder, XmrAddrEncoder,
-    XrpAddrEncoder, XtzAddrPrefixes, XtzAddrEncoder, ZilAddrEncoder
+    AdaByronIcarusAddrEncoder, AlgoAddrEncoder, AtomAddrEncoder, AvaxPChainAddrEncoder, AvaxXChainAddrEncoder,
+    BchP2PKHAddrEncoder, EgldAddrEncoder, EosAddrEncoder, ErgoNetworkTypes, ErgoP2PKHAddrEncoder, EthAddrEncoder,
+    FilSecp256k1AddrEncoder, NanoAddrEncoder, NearAddrEncoder, NeoAddrEncoder, OkexAddrEncoder, OneAddrEncoder,
+    P2PKHAddrEncoder, SolAddrEncoder, SubstrateEd25519AddrEncoder, TrxAddrEncoder, XlmAddrEncoder, XlmAddrTypes,
+    XmrAddrEncoder, XrpAddrEncoder, XtzAddrEncoder, XtzAddrPrefixes, ZilAddrEncoder
 )
 from bip_utils.bip.bip32 import (
-    Bip32Const, Bip32KeyNetVersions, Bip32Ed25519Slip, Bip32Ed25519Blake2bSlip, Bip32Nist256p1, Bip32Secp256k1
+    Bip32Const, Bip32KeyNetVersions, Bip32KholawEd25519, Bip32Slip10Ed25519, Bip32Slip10Ed25519Blake2b,
+    Bip32Slip10Nist256p1, Bip32Slip10Secp256k1
 )
 from bip_utils.bip.conf.common import (
-    BipCoinConf, BipBitcoinCashConf, BipLitecoinConf, HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH
+    HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH, BipBitcoinCashConf, BipCoinConf, BipCoinFctCallsConf, BipLitecoinConf
 )
+from bip_utils.cardano.bip32.cardano_icarus_bip32 import CardanoIcarusBip32
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.slip.slip44 import Slip44
 
-
 # Bitcoin key net version for main net (same as BIP32)
 _BIP44_BTC_KEY_NET_VER_MAIN: Bip32KeyNetVersions = Bip32Const.MAIN_NET_KEY_NET_VERSIONS
 # Bitcoin key net version for test net (same as BIP32)
@@ -45,7 +46,7 @@ _BIP44_BTC_KEY_NET_VER_TEST: Bip32KeyNetVersions = Bip32Const.TEST_NET_KEY_NET_V
 
 
 class Bip44Conf:
-    """Class container for Bip44 configuration."""
+    """Class container for BIP44 configuration."""
 
     # Configuration for Akash Network
     AkashNetwork: BipCoinConf = BipCoinConf(
@@ -55,10 +56,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.AkashNetwork.Params("addr_hrp"),
+            "hrp": CoinsConf.AkashNetwork.ParamByKey("addr_hrp"),
         },
     )
 
@@ -70,7 +71,7 @@ class Bip44Conf:
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=AlgoAddrEncoder,
         addr_params={},
     )
@@ -83,7 +84,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -95,7 +96,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AvaxPChainAddrEncoder,
         addr_params={},
     )
@@ -107,7 +108,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AvaxXChainAddrEncoder,
         addr_params={},
     )
@@ -120,10 +121,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Axelar.Params("addr_hrp"),
+            "hrp": CoinsConf.Axelar.ParamByKey("addr_hrp"),
         },
     )
 
@@ -135,10 +136,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.BandProtocol.Params("addr_hrp"),
+            "hrp": CoinsConf.BandProtocol.ParamByKey("addr_hrp"),
         },
     )
 
@@ -150,10 +151,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.BinanceChain.Params("addr_hrp"),
+            "hrp": CoinsConf.BinanceChain.ParamByKey("addr_hrp"),
         },
     )
     # Configuration for Binance Smart Chain
@@ -164,7 +165,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -176,11 +177,11 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.BitcoinMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.BitcoinMainNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.BitcoinMainNet.ParamByKey("p2pkh_net_ver"),
         },
     )
     # Configuration for Bitcoin test net
@@ -190,11 +191,11 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.BitcoinTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.BitcoinTestNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.BitcoinTestNet.ParamByKey("p2pkh_net_ver"),
         },
     )
 
@@ -205,16 +206,16 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.BitcoinCashMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinCashMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.BitcoinCashMainNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.BitcoinCashMainNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.BitcoinCashMainNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.BitcoinCashMainNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.BitcoinCashMainNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.BitcoinCashMainNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -226,16 +227,16 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.BitcoinCashTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinCashTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.BitcoinCashTestNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.BitcoinCashTestNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.BitcoinCashTestNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.BitcoinCashTestNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.BitcoinCashTestNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.BitcoinCashTestNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -248,16 +249,16 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.BitcoinCashSlpMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinCashSlpMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.BitcoinCashSlpMainNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.BitcoinCashSlpMainNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.BitcoinCashSlpMainNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.BitcoinCashSlpMainNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.BitcoinCashSlpMainNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.BitcoinCashSlpMainNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -269,16 +270,16 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.BitcoinCashSlpTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinCashSlpTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.BitcoinCashSlpTestNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.BitcoinCashSlpTestNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.BitcoinCashSlpTestNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.BitcoinCashSlpTestNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.BitcoinCashSlpTestNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.BitcoinCashSlpTestNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -291,11 +292,11 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.BitcoinSvMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinSvMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.BitcoinSvMainNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.BitcoinSvMainNet.ParamByKey("p2pkh_net_ver"),
         },
     )
     # Configuration for BitcoinSV test net
@@ -305,11 +306,40 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.BitcoinSvTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.BitcoinSvTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.BitcoinSvTestNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.BitcoinSvTestNet.ParamByKey("p2pkh_net_ver"),
+        },
+    )
+
+    # Configuration for Cardano Byron (Icarus)
+    CardanoByronIcarus: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.CardanoMainNet.CoinNames(),
+        coin_idx=Slip44.CARDANO,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=Bip32Const.KHOLAW_KEY_NET_VERSIONS,
+        wif_net_ver=None,
+        bip32_cls=CardanoIcarusBip32,
+        addr_cls=AdaByronIcarusAddrEncoder,
+        addr_params={
+            "chain_code": BipCoinFctCallsConf("ChainCode"),
+        },
+    )
+    # Configuration for Cardano Byron (Ledger)
+    CardanoByronLedger: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.CardanoMainNet.CoinNames(),
+        coin_idx=Slip44.CARDANO,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=Bip32Const.KHOLAW_KEY_NET_VERSIONS,
+        wif_net_ver=None,
+        bip32_cls=Bip32KholawEd25519,
+        addr_cls=AdaByronIcarusAddrEncoder,
+        addr_params={
+            "chain_code": BipCoinFctCallsConf("ChainCode"),
         },
     )
 
@@ -321,7 +351,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -334,10 +364,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Certik.Params("addr_hrp"),
+            "hrp": CoinsConf.Certik.ParamByKey("addr_hrp"),
         },
     )
 
@@ -349,10 +379,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Chihuahua.Params("addr_hrp"),
+            "hrp": CoinsConf.Chihuahua.ParamByKey("addr_hrp"),
         },
     )
 
@@ -364,10 +394,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Cosmos.Params("addr_hrp"),
+            "hrp": CoinsConf.Cosmos.ParamByKey("addr_hrp"),
         },
     )
 
@@ -378,11 +408,11 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.DashMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.DashMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.DashMainNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.DashMainNet.ParamByKey("p2pkh_net_ver"),
         },
     )
     # Configuration for Dash test net
@@ -392,11 +422,11 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.DashTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.DashTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.DashTestNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.DashTestNet.ParamByKey("p2pkh_net_ver"),
         },
     )
 
@@ -408,11 +438,11 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=Bip32KeyNetVersions(b"\x02\xfa\xca\xfd",
                                         b"\x02\xfa\xc3\x98"),   # dgub / dgpv
-        wif_net_ver=CoinsConf.DogecoinMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.DogecoinMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.DogecoinMainNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.DogecoinMainNet.ParamByKey("p2pkh_net_ver"),
         },
     )
     # Configuration for Dogecoin test net
@@ -423,11 +453,11 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=Bip32KeyNetVersions(b"\x04\x32\xa9\xa8",
                                         b"\x04\x32\xa2\x43"),   # tgub / tgpv
-        wif_net_ver=CoinsConf.DogecoinTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.DogecoinTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.DogecoinTestNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.DogecoinTestNet.ParamByKey("p2pkh_net_ver"),
         },
     )
 
@@ -438,16 +468,16 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.EcashMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.EcashMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.EcashMainNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.EcashMainNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.EcashMainNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.EcashMainNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.EcashMainNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.EcashMainNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -459,16 +489,16 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.EcashTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.EcashTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
-                "net_ver": CoinsConf.EcashTestNet.Params("p2pkh_std_net_ver"),
-                "hrp": CoinsConf.EcashTestNet.Params("p2pkh_std_hrp"),
+                "net_ver": CoinsConf.EcashTestNet.ParamByKey("p2pkh_std_net_ver"),
+                "hrp": CoinsConf.EcashTestNet.ParamByKey("p2pkh_std_hrp"),
             },
             "legacy": {
-                "net_ver": CoinsConf.EcashTestNet.Params("p2pkh_legacy_net_ver"),
+                "net_ver": CoinsConf.EcashTestNet.ParamByKey("p2pkh_legacy_net_ver"),
             }
         },
         addr_cls_legacy=P2PKHAddrEncoder,
@@ -482,7 +512,7 @@ class Bip44Conf:
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=EgldAddrEncoder,
         addr_params={},
     )
@@ -495,11 +525,41 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EosAddrEncoder,
         addr_params={},
     )
 
+    # Configuration for Ergo main net
+    ErgoMainNet: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.ErgoMainNet.CoinNames(),
+        coin_idx=Slip44.ERGO,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Slip10Secp256k1,
+        addr_cls=ErgoP2PKHAddrEncoder,
+        addr_params={
+            "net_type": ErgoNetworkTypes.MAINNET,
+        },
+    )
+
+    # Configuration for Ergo test net
+    ErgoTestNet: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.ErgoTestNet.CoinNames(),
+        coin_idx=Slip44.ERGO,
+        is_testnet=True,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
+        wif_net_ver=None,
+        bip32_cls=Bip32Slip10Secp256k1,
+        addr_cls=ErgoP2PKHAddrEncoder,
+        addr_params={
+            "net_type": ErgoNetworkTypes.TESTNET,
+        },
+    )
+
     # Configuration for Ethereum
     Ethereum: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Ethereum.CoinNames(),
@@ -508,7 +568,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -520,7 +580,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -533,7 +593,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -546,7 +606,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=FilSecp256k1AddrEncoder,
         addr_params={},
     )
@@ -559,7 +619,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -571,7 +631,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -583,7 +643,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=OneAddrEncoder,
         addr_params={},
     )
@@ -596,7 +656,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -609,10 +669,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.IrisNet.Params("addr_hrp"),
+            "hrp": CoinsConf.IrisNet.ParamByKey("addr_hrp"),
         },
     )
 
@@ -624,10 +684,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Kava.Params("addr_hrp"),
+            "hrp": CoinsConf.Kava.ParamByKey("addr_hrp"),
         },
     )
 
@@ -639,10 +699,10 @@ class Bip44Conf:
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=SubstrateEd25519AddrEncoder,
         addr_params={
-            "ss58_format": CoinsConf.Kusama.Params("addr_ss58_format"),
+            "ss58_format": CoinsConf.Kusama.ParamByKey("addr_ss58_format"),
         },
     )
 
@@ -655,12 +715,12 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         alt_key_net_ver=Bip32KeyNetVersions(b"\x01\x9d\xa4\x62",
                                             b"\x01\x9d\x9c\xfe"),   # Ltpv / Ltub
-        wif_net_ver=CoinsConf.LitecoinMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.LitecoinMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "std_net_ver": CoinsConf.LitecoinMainNet.Params("p2pkh_std_net_ver"),
-            "depr_net_ver": CoinsConf.LitecoinMainNet.Params("p2pkh_depr_net_ver"),
+            "std_net_ver": CoinsConf.LitecoinMainNet.ParamByKey("p2pkh_std_net_ver"),
+            "depr_net_ver": CoinsConf.LitecoinMainNet.ParamByKey("p2pkh_depr_net_ver"),
         },
     )
     # Configuration for Litecoin test net
@@ -673,12 +733,12 @@ class Bip44Conf:
                                         b"\x04\x36\xef\x7d"),       # ttub / ttpv
         alt_key_net_ver=Bip32KeyNetVersions(b"\x04\x36\xf6\xe1",
                                             b"\x04\x36\xef\x7d"),   # ttub / ttpv
-        wif_net_ver=CoinsConf.LitecoinTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.LitecoinTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "std_net_ver": CoinsConf.LitecoinTestNet.Params("p2pkh_std_net_ver"),
-            "depr_net_ver": CoinsConf.LitecoinTestNet.Params("p2pkh_depr_net_ver"),
+            "std_net_ver": CoinsConf.LitecoinTestNet.ParamByKey("p2pkh_std_net_ver"),
+            "depr_net_ver": CoinsConf.LitecoinTestNet.ParamByKey("p2pkh_depr_net_ver"),
         },
     )
 
@@ -690,7 +750,7 @@ class Bip44Conf:
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=XmrAddrEncoder,
         addr_params={},
     )
@@ -703,7 +763,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=XmrAddrEncoder,
         addr_params={},
     )
@@ -716,7 +776,7 @@ class Bip44Conf:
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Blake2bSlip,
+        bip32_cls=Bip32Slip10Ed25519Blake2b,
         addr_cls=NanoAddrEncoder,
         addr_params={},
     )
@@ -729,7 +789,7 @@ class Bip44Conf:
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=NearAddrEncoder,
         addr_params={},
     )
@@ -742,10 +802,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Nist256p1,
+        bip32_cls=Bip32Slip10Nist256p1,
         addr_cls=NeoAddrEncoder,
         addr_params={
-            "ver": CoinsConf.Neo.Params("addr_ver"),
+            "ver": CoinsConf.Neo.ParamByKey("addr_ver"),
         },
     )
 
@@ -757,7 +817,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -770,7 +830,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -783,7 +843,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=OkexAddrEncoder,
         addr_params={},
     )
@@ -796,7 +856,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=OkexAddrEncoder,
         addr_params={},
     )
@@ -809,10 +869,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Nist256p1,
+        bip32_cls=Bip32Slip10Nist256p1,
         addr_cls=NeoAddrEncoder,
         addr_params={
-            "ver": CoinsConf.Ontology.Params("addr_ver"),
+            "ver": CoinsConf.Ontology.ParamByKey("addr_ver"),
         },
     )
 
@@ -824,10 +884,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Osmosis.Params("addr_hrp"),
+            "hrp": CoinsConf.Osmosis.ParamByKey("addr_hrp"),
         },
     )
 
@@ -839,10 +899,10 @@ class Bip44Conf:
         def_path=HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=SubstrateEd25519AddrEncoder,
         addr_params={
-            "ss58_format": CoinsConf.Polkadot.Params("addr_ss58_format"),
+            "ss58_format": CoinsConf.Polkadot.ParamByKey("addr_ss58_format"),
         },
     )
 
@@ -854,7 +914,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -867,7 +927,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=XrpAddrEncoder,
         addr_params={},
     )
@@ -880,10 +940,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.SecretNetwork.Params("addr_hrp"),
+            "hrp": CoinsConf.SecretNetwork.ParamByKey("addr_hrp"),
         },
     )
     # Configuration for Secret Network (new path)
@@ -894,10 +954,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.SecretNetwork.Params("addr_hrp"),
+            "hrp": CoinsConf.SecretNetwork.ParamByKey("addr_hrp"),
         },
     )
 
@@ -909,7 +969,7 @@ class Bip44Conf:
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=SolAddrEncoder,
         addr_params={},
     )
@@ -922,7 +982,7 @@ class Bip44Conf:
         def_path="0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=XlmAddrEncoder,
         addr_params={"addr_type": XlmAddrTypes.PUB_KEY},
     )
@@ -935,10 +995,10 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=AtomAddrEncoder,
         addr_params={
-            "hrp": CoinsConf.Terra.Params("addr_hrp"),
+            "hrp": CoinsConf.Terra.ParamByKey("addr_hrp"),
         },
     )
 
@@ -950,7 +1010,7 @@ class Bip44Conf:
         def_path="0'/0'",
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Ed25519Slip,
+        bip32_cls=Bip32Slip10Ed25519,
         addr_cls=XtzAddrEncoder,
         addr_params={"prefix": XtzAddrPrefixes.TZ1},
     )
@@ -963,7 +1023,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -976,7 +1036,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=TrxAddrEncoder,
         addr_params={},
     )
@@ -989,7 +1049,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=EthAddrEncoder,
         addr_params={},
     )
@@ -1001,11 +1061,11 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.Verge.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.Verge.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.Verge.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.Verge.ParamByKey("p2pkh_net_ver"),
         },
     )
 
@@ -1016,11 +1076,11 @@ class Bip44Conf:
         is_testnet=False,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
-        wif_net_ver=CoinsConf.ZcashMainNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.ZcashMainNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.ZcashMainNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.ZcashMainNet.ParamByKey("p2pkh_net_ver"),
         },
     )
     # Configuration for Zcash test net
@@ -1030,11 +1090,11 @@ class Bip44Conf:
         is_testnet=True,
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
-        wif_net_ver=CoinsConf.ZcashTestNet.Params("wif_net_ver"),
-        bip32_cls=Bip32Secp256k1,
+        wif_net_ver=CoinsConf.ZcashTestNet.ParamByKey("wif_net_ver"),
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=P2PKHAddrEncoder,
         addr_params={
-            "net_ver": CoinsConf.ZcashTestNet.Params("p2pkh_net_ver"),
+            "net_ver": CoinsConf.ZcashTestNet.ParamByKey("p2pkh_net_ver"),
         },
     )
 
@@ -1046,7 +1106,7 @@ class Bip44Conf:
         def_path=NOT_HARDENED_DEF_PATH,
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
-        bip32_cls=Bip32Secp256k1,
+        bip32_cls=Bip32Slip10Secp256k1,
         addr_cls=ZilAddrEncoder,
         addr_params={},
     )
