@@ -25,7 +25,6 @@ from bip_utils.coin_conf.coin_conf import CoinConf
 from bip_utils.slip.slip173 import Slip173
 from bip_utils.utils.conf import CoinNames
 
-
 # Bitcoin constants used by different coins
 # Main net
 _BTC_P2PKH_NET_VER_MN: bytes = b"\x00"
@@ -236,6 +235,24 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Cardano main net
+    CardanoMainNet: CoinConf = CoinConf(
+        coin_name=CoinNames("Cardano", "ADA"),
+        params={
+            "addr_hrp": "addr",
+            "staking_addr_hrp": "stake",
+        },
+    )
+
+    # Configuration for Cardano test
+    CardanoTestNet: CoinConf = CoinConf(
+        coin_name=CoinNames("Cardano TestNet", "ADA"),
+        params={
+            "addr_hrp": "addr_test",
+            "staking_addr_hrp": "stake_test",
+        },
+    )
+
     # Configuration for Celo
     Celo: CoinConf = CoinConf(
         coin_name=CoinNames("Celo", "CELO"),
@@ -366,6 +383,18 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Ergo main net
+    ErgoMainNet: CoinConf = CoinConf(
+        coin_name=CoinNames("Ergo", "ERGO"),
+        params={},
+    )
+
+    # Configuration for Ergo test net
+    ErgoTestNet: CoinConf = CoinConf(
+        coin_name=CoinNames("Ergo TestNet", "ERGO"),
+        params={},
+    )
+
     # Configuration for Ethereum
     Ethereum: CoinConf = CoinConf(
         coin_name=CoinNames("Ethereum", "ETH"),
