@@ -22,17 +22,20 @@
 
 # Imports
 from __future__ import annotations
+
 from abc import ABC, abstractmethod
 from functools import lru_cache
+from typing import Union
+
 from bip_utils.addr import P2PKHAddr, P2WPKHAddr
-from bip_utils.bip.bip32 import Bip32PrivateKey, Bip32PublicKey, Bip32Base, Bip32Secp256k1
+from bip_utils.bip.bip32 import Bip32Base, Bip32KeyIndex, Bip32PrivateKey, Bip32PublicKey, Bip32Slip10Secp256k1
 from bip_utils.coin_conf import CoinsConf
 
 
 class ElectrumV2Base(ABC):
     """Electrum v2 base class."""
 
-    m_bip32: Bip32Base
+    m_bip32_obj: Bip32Base
 
     @classmethod
     def FromSeed(cls,
@@ -46,25 +49,25 @@ class ElectrumV2Base(ABC):
         Returns:
             ElectrumV2Base object: ElectrumV2Base object
         """
-        return cls(Bip32Secp256k1.FromSeed(seed_bytes))
+        return cls(Bip32Slip10Secp256k1.FromSeed(seed_bytes))
 
     def __init__(self,
-                 bip32: Bip32Base) -> None:
+                 bip32_obj: Bip32Base) -> None:
         """
         Construct class.
 
         Args:
-            bip32 (Bip32Base object): Bip32Base object (shall be a Bip32Secp256k1 instance)
+            bip32_obj (Bip32Base object): Bip32Base object (shall be a Bip32Slip10Secp256k1 instance)
 
         Raises:
-            TypeError: If the bip32 object is not a Bip32Secp256k1 class instance
+            TypeError: If the bip32 object is not a Bip32Slip10Secp256k1 class instance
             ValueError: If the bip32 object is not a master key
         """
-        if not isinstance(bip32, Bip32Secp256k1):
-            raise TypeError("A Bip32Secp256k1 class instance is required")
-        if bip32.Depth() > 0:
+        if not isinstance(bip32_obj, Bip32Slip10Secp256k1):
+            raise TypeError("A Bip32Slip10Secp256k1 class instance is required")
+        if bip32_obj.Depth() > 0:
             raise ValueError("The Bip32 object shall be a master key (i.e. depth equal to 0)")
-        self.m_bip32 = bip32
+        self.m_bip32_obj = bip32_obj
 
     def Bip32Object(self) -> Bip32Base:
         """
@@ -73,7 +76,7 @@ class ElectrumV2Base(ABC):
         Returns:
             Bip32Base object: Bip32Base object
         """
-        return self.m_bip32
+        return self.m_bip32_obj
 
     def IsPublicOnly(self) -> bool:
         """
@@ -82,7 +85,7 @@ class ElectrumV2Base(ABC):
         Returns:
             bool: True if public-only, false otherwise
         """
-        return self.m_bip32.IsPublicOnly()
+        return self.m_bip32_obj.IsPublicOnly()
 
     def MasterPrivateKey(self) -> Bip32PrivateKey:
         """
@@ -91,60 +94,72 @@ class ElectrumV2Base(ABC):
         Returns:
             Bip32PrivateKey object: Bip32PrivateKey object
         """
-        return self.m_bip32.PrivateKey()
+        return self.m_bip32_obj.PrivateKey()
 
     def MasterPublicKey(self) -> Bip32PublicKey:
         """
         Get the master public key.
 
         Returns:
-            Bip32PrivateKey object: Bip32PrivateKey object
+            Bip32PublicKey object: Bip32PublicKey object
         """
-        return self.m_bip32.PublicKey()
+        return self.m_bip32_obj.PublicKey()
 
     @abstractmethod
     def GetPrivateKey(self,
-                      change_idx: int,
-                      addr_idx: int) -> Bip32PrivateKey:
+                      change_idx: Union[int, Bip32KeyIndex],
+                      addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PrivateKey:
         """
         Get the private key with the specified change and address indexes.
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PrivateKey object: Bip32PrivateKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key or the object is public-only
+            Bip32PathError: If the path indexes are not valid
         """
 
     @abstractmethod
     def GetPublicKey(self,
-                     change_idx: int,
-                     addr_idx: int) -> Bip32PublicKey:
+                     change_idx: Union[int, Bip32KeyIndex],
+                     addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PublicKey:
         """
         Get the public key with the specified change and address indexes.
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PublicKey object: Bip32PublicKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
 
     @abstractmethod
     def GetAddress(self,
-                   change_idx: int,
-                   addr_idx: int) -> str:
+                   change_idx: Union[int, Bip32KeyIndex],
+                   addr_idx: Union[int, Bip32KeyIndex]) -> str:
         """
         Get the address with the specified change and address indexes.
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             str: Address
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
 
 
@@ -155,66 +170,87 @@ class ElectrumV2Standard(ElectrumV2Base):
     """
 
     def GetPrivateKey(self,
-                      change_idx: int,
-                      addr_idx: int) -> Bip32PrivateKey:
+                      change_idx: Union[int, Bip32KeyIndex],
+                      addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PrivateKey:
         """
         Get the private key with the specified change and address indexes.
+        Derivation path: m/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PrivateKey object: Bip32PrivateKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key or the object is public-only
+            Bip32PathError: If the path indexes are not valid
         """
         return self.__DeriveKey(change_idx, addr_idx).PrivateKey()
 
     def GetPublicKey(self,
-                     change_idx: int,
-                     addr_idx: int) -> Bip32PublicKey:
+                     change_idx: Union[int, Bip32KeyIndex],
+                     addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PublicKey:
         """
         Get the public key with the specified change and address indexes.
+        Derivation path: m/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PublicKey object: Bip32PublicKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
         return self.__DeriveKey(change_idx, addr_idx).PublicKey()
 
+    @lru_cache()
     def GetAddress(self,
-                   change_idx: int,
-                   addr_idx: int) -> str:
+                   change_idx: Union[int, Bip32KeyIndex],
+                   addr_idx: Union[int, Bip32KeyIndex]) -> str:
         """
         Get the address with the specified change and address indexes.
+        Derivation path: m/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             str: Address
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
         return P2PKHAddr.EncodeKey(self.GetPublicKey(change_idx, addr_idx).KeyObject(),
-                                   net_ver=CoinsConf.BitcoinMainNet.Params("p2pkh_net_ver"))
+                                   net_ver=CoinsConf.BitcoinMainNet.ParamByKey("p2pkh_net_ver"))
 
     @lru_cache()
     def __DeriveKey(self,
-                    change_idx: int,
-                    addr_idx: int) -> Bip32Base:
+                    change_idx: Union[int, Bip32KeyIndex],
+                    addr_idx: Union[int, Bip32KeyIndex]) -> Bip32Base:
         """
         Derive the key with the specified change and address indexes.
+        Derivation path: m/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32Base object: Bip32Base object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
-        return self.m_bip32.DerivePath(f"m/{change_idx}/{addr_idx}")
+        return self.m_bip32_obj.DerivePath(f"m/{change_idx}/{addr_idx}")
 
 
 class ElectrumV2Segwit(ElectrumV2Base):
@@ -237,63 +273,84 @@ class ElectrumV2Segwit(ElectrumV2Base):
         self.m_bip32_acc = bip32.DerivePath("m/0'")
 
     def GetPrivateKey(self,
-                      change_idx: int,
-                      addr_idx: int) -> Bip32PrivateKey:
+                      change_idx: Union[int, Bip32KeyIndex],
+                      addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PrivateKey:
         """
         Get the private key with the specified change and address indexes.
+        Derivation path: m/0'/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PrivateKey object: Bip32PrivateKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key or the object is public-only
+            Bip32PathError: If the path indexes are not valid
         """
         return self.__DeriveKey(change_idx, addr_idx).PrivateKey()
 
     def GetPublicKey(self,
-                     change_idx: int,
-                     addr_idx: int) -> Bip32PublicKey:
+                     change_idx: Union[int, Bip32KeyIndex],
+                     addr_idx: Union[int, Bip32KeyIndex]) -> Bip32PublicKey:
         """
         Get the public key with the specified change and address indexes.
+        Derivation path: m/0'/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32PublicKey object: Bip32PublicKey object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
         return self.__DeriveKey(change_idx, addr_idx).PublicKey()
 
+    @lru_cache()
     def GetAddress(self,
-                   change_idx: int,
-                   addr_idx: int) -> str:
+                   change_idx: Union[int, Bip32KeyIndex],
+                   addr_idx: Union[int, Bip32KeyIndex]) -> str:
         """
         Get the address with the specified change and address indexes.
+        Derivation path: m/0'/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             str: Address
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
         return P2WPKHAddr.EncodeKey(self.GetPublicKey(change_idx, addr_idx).KeyObject(),
-                                    hrp=CoinsConf.BitcoinMainNet.Params("p2wpkh_hrp"))
+                                    hrp=CoinsConf.BitcoinMainNet.ParamByKey("p2wpkh_hrp"))
 
     @lru_cache()
     def __DeriveKey(self,
-                    change_idx: int,
-                    addr_idx: int) -> Bip32Base:
+                    change_idx: Union[int, Bip32KeyIndex],
+                    addr_idx: Union[int, Bip32KeyIndex]) -> Bip32Base:
         """
         Derive the key with the specified change and address indexes.
+        Derivation path: m/0'/change_idx/addr_idx
 
         Args:
-            change_idx (int): Change index
-            addr_idx (int)  : Address index
+            change_idx (int or Bip32KeyIndex object): Change index
+            addr_idx (int or Bip32KeyIndex object)  : Address index
 
         Returns:
             Bip32Base object: Bip32Base object
+
+        Raises:
+            Bip32KeyError: If the derivation results in an invalid key
+            Bip32PathError: If the path indexes are not valid
         """
         return self.m_bip32_acc.DerivePath(f"{change_idx}/{addr_idx}")
