@@ -1,4 +1,4 @@
-from bip_utils.monero.monero_ex import MoneroKeyError
 from bip_utils.monero.monero import Monero
-from bip_utils.monero.monero_keys import MoneroPublicKey, MoneroPrivateKey
+from bip_utils.monero.monero_ex import MoneroKeyError
+from bip_utils.monero.monero_keys import MoneroPrivateKey, MoneroPublicKey
 from bip_utils.monero.monero_subaddr import MoneroSubaddress
