@@ -22,11 +22,14 @@
 
 # Imports
 from typing import List, Optional, Union
-from bip_utils.monero.mnemonic.monero_mnemonic import MoneroMnemonicConst, MoneroLanguages, MoneroMnemonic
+
+from bip_utils.monero.mnemonic.monero_mnemonic import MoneroLanguages, MoneroMnemonic, MoneroMnemonicConst
 from bip_utils.monero.mnemonic.monero_mnemonic_utils import (
-    MoneroWordsListFinder, MoneroWordsListGetter, MoneroMnemonicUtils
+    MoneroMnemonicUtils, MoneroWordsListFinder, MoneroWordsListGetter
+)
+from bip_utils.utils.mnemonic import (
+    Mnemonic, MnemonicChecksumError, MnemonicDecoderBase, MnemonicLanguages, MnemonicUtils
 )
-from bip_utils.utils.mnemonic import MnemonicChecksumError, Mnemonic, MnemonicDecoderBase, MnemonicUtils
 
 
 class MoneroMnemonicDecoder(MnemonicDecoderBase):
@@ -94,13 +97,13 @@ class MoneroMnemonicDecoder(MnemonicDecoderBase):
 
     @staticmethod
     def __ValidateChecksum(words: List[str],
-                           lang: MoneroLanguages) -> None:
+                           lang: MnemonicLanguages) -> None:
         """
         Validate a mnemonic checksum.
 
         Args:
-            words (list[str])     : Words list
-            lang (MoneroLanguages): Language
+            words (list[str])       : Words list
+            lang (MnemonicLanguages): Language
 
         Raises:
             MnemonicChecksumError: If checksum is not valid
