@@ -22,15 +22,18 @@
 
 # Imports
 from __future__ import annotations
+
 from functools import lru_cache
 from typing import Optional, Union
+
 from bip_utils.addr import XmrIntegratedAddrEncoder
 from bip_utils.ecc import Ed25519Monero, Ed25519MoneroPrivateKey, IPrivateKey, IPublicKey
-from bip_utils.monero.conf import MoneroCoins, MoneroCoinConf, MoneroConfGetter
+from bip_utils.monero.conf import MoneroCoinConf, MoneroCoins, MoneroConfGetter
 from bip_utils.monero.monero_ex import MoneroKeyError
 from bip_utils.monero.monero_keys import MoneroPrivateKey, MoneroPublicKey
 from bip_utils.monero.monero_subaddr import MoneroSubaddress
-from bip_utils.utils.misc import BytesUtils, CryptoUtils, IntegerUtils
+from bip_utils.utils.crypto import Kekkak256
+from bip_utils.utils.misc import BytesUtils, IntegerUtils
 
 
 class _MoneroUtils:
@@ -81,7 +84,7 @@ class Monero:
         """
         priv_skey_bytes = (seed_bytes
                            if len(seed_bytes) == Ed25519MoneroPrivateKey.Length()
-                           else CryptoUtils.Kekkak256(seed_bytes))
+                           else Kekkak256.QuickDigest(seed_bytes))
         return cls.FromPrivateSpendKey(_MoneroUtils.ScReduce(priv_skey_bytes), coin_type)
 
     @classmethod
@@ -100,7 +103,10 @@ class Monero:
         """
         if not isinstance(priv_key, bytes):
             priv_key = priv_key.Raw().ToBytes()
-        return cls.FromPrivateSpendKey(_MoneroUtils.ScReduce(CryptoUtils.Kekkak256(priv_key)), coin_type)
+        return cls.FromPrivateSpendKey(
+            _MoneroUtils.ScReduce(Kekkak256.QuickDigest(priv_key)),
+            coin_type
+        )
 
     @classmethod
     def FromPrivateSpendKey(cls,
@@ -302,5 +308,5 @@ class Monero:
         Returns:
             MoneroPrivateKey object: Private view key
         """
-        priv_vkey_bytes = _MoneroUtils.ScReduce(CryptoUtils.Kekkak256(priv_skey.Raw().ToBytes()))
+        priv_vkey_bytes = _MoneroUtils.ScReduce(Kekkak256.QuickDigest(priv_skey.Raw().ToBytes()))
         return MoneroPrivateKey.FromBytes(priv_vkey_bytes)
