@@ -2,6 +2,6 @@ from bip_utils.substrate.scale.substrate_scale_enc_base import SubstrateScaleEnc
 from bip_utils.substrate.scale.substrate_scale_enc_bytes import SubstrateScaleBytesEncoder
 from bip_utils.substrate.scale.substrate_scale_enc_cuint import SubstrateScaleCUintEncoder
 from bip_utils.substrate.scale.substrate_scale_enc_uint import (
-    SubstrateScaleU8Encoder, SubstrateScaleU16Encoder, SubstrateScaleU32Encoder,
-    SubstrateScaleU64Encoder, SubstrateScaleU128Encoder, SubstrateScaleU256Encoder
+    SubstrateScaleU8Encoder, SubstrateScaleU16Encoder, SubstrateScaleU32Encoder, SubstrateScaleU64Encoder,
+    SubstrateScaleU128Encoder, SubstrateScaleU256Encoder
 )
